gchecky.model.hello_t

Package gchecky :: Module model :: Class hello_t |
[hide private]
[frames] | no frames]

# Class hello_t

source code

    object --+
             |
     gxml.Node --+
                 |
     gxml.Document --+
                     |
                    hello_t

Represents a simple test that verifies that your server communicates properly with Google Checkout. The fourth step of the Getting Started with Google Checkout section of the Developer's Guide explains how to execute this test.

    >>> test_document(hello_t(),
    ...               "<hello xmlns='http://checkout.google.com/schema/2'/>"
    ... )

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``hello``'`` The document's unique xml tag name.
Inherited from `gxml.Node` (private): `_fields`

Properties | [hide private]
Inherited from `object`: `__class__`